cntnr
=====

CLI wrapper for basic container (Docker/libpod) management tasks


## About

This is a Python wrapper script to simplify specific tasks in a container environment.
It is designed to work with your container runtime of choice (currently `podman` and `docker`).
A CLI menu makes these selections possible.

This project was created for a lab assignment in NSSA-244 Virtualization at the [Rochester Institute of Technology](https://www.rit.edu/).


## Legal

Licensed under Mozilla Public License 2.0.
Created by Justin W. Flory.
